@@ -31,13 +31,23 @@ pub trait Display
 
 /// A trait for any bar with progress. You can implemnent your own styles through this trait.
 pub trait ProgressBar: Display
-{   
+{
     fn set_progress(&mut self, value: f64);
     fn get_progress(&self) -> f64;
 }
 
 /// A trait for any bar without progress. You can implemnent your own styles through this trait.
 pub trait Spinner: Display
-{   
+{
+    /// Cause the spinner to increment once.
     fn bump(&mut self);
 }
+
+/// A trait for creating a progress bar or spinner with a title.
+pub trait WithTitle: Sized + Display
+{
+    fn with_title(len: usize, string: impl AsRef<str>) -> Self;
+    fn update(&mut self);
+    fn complete(self);
+}
+
