@@ -119,3 +119,17 @@ impl Spinner for Spin
 	self.refresh();
     }
 }
+
+
+impl WithTitle for Spin
+{
+    fn with_title(_: usize, t: impl AsRef<str>) -> Self
+    {
+	Self::with_title(t.as_ref(), Default::default())
+    }
+    #[inline] fn update(&mut self){}
+    #[inline] fn complete(self)
+    {
+	Spin::complete(self)
+    }
+}
